@@ -3,8 +3,7 @@ use std::iter::FromIterator;
 use crate::key::Key;
 use crate::repr::Decor;
 use crate::table::{Iter, IterMut, KeyValuePairs, TableKeyValue, TableLike};
-use crate::value::{DEFAULT_TRAILING_VALUE_DECOR, DEFAULT_VALUE_DECOR};
-use crate::{InternalString, Item, Table, Value};
+use crate::{InternalString, Item, KeyMut, Table, Value};
 
 /// Type representing a TOML inline table,
 /// payload of the `Value::InlineTable` variant
@@ -37,7 +36,9 @@ impl InlineTable {
 
     /// Convert to a table
     pub fn into_table(self) -> Table {
-        Table::with_pairs(self.items)
+        let mut t = Table::with_pairs(self.items);
+        t.fmt();
+        t
     }
 }
 
@@ -140,7 +141,7 @@ impl InlineTable {
             self.items
                 .iter_mut()
                 .filter(|(_, kv)| kv.value.is_value())
-                .map(|(k, kv)| (&k[..], kv.value.as_value_mut().unwrap())),
+                .map(|(_, kv)| (kv.key.as_mut(), kv.value.as_value_mut().unwrap())),
         )
     }
 
@@ -328,24 +329,14 @@ impl<'s> IntoIterator for &'s InlineTable {
 }
 
 fn decorate_inline_table(table: &mut InlineTable) {
-    let n = table.len();
-    for (i, (key_decor, value)) in table
+    for (key_decor, value) in table
         .items
         .iter_mut()
         .filter(|&(_, ref kv)| kv.value.is_value())
         .map(|(_, kv)| (&mut kv.key.decor, kv.value.as_value_mut().unwrap()))
-        .enumerate()
     {
-        // { key1 = value1, key2 = value2 }
-        *key_decor = Decor::new(DEFAULT_INLINE_KEY_DECOR.0, DEFAULT_INLINE_KEY_DECOR.1);
-        if i == n - 1 {
-            value.decorate(
-                DEFAULT_TRAILING_VALUE_DECOR.0,
-                DEFAULT_TRAILING_VALUE_DECOR.1,
-            );
-        } else {
-            value.decorate(DEFAULT_VALUE_DECOR.0, DEFAULT_VALUE_DECOR.1);
-        }
+        key_decor.clear();
+        value.decor_mut().clear();
     }
 }
 
@@ -354,7 +345,7 @@ pub type InlineTableIntoIter = Box<dyn Iterator<Item = (InternalString, Value)>>
 /// An iterator type over key/value pairs of an inline table.
 pub type InlineTableIter<'a> = Box<dyn Iterator<Item = (&'a str, &'a Value)> + 'a>;
 /// A mutable iterator type over key/value pairs of an inline table.
-pub type InlineTableIterMut<'a> = Box<dyn Iterator<Item = (&'a str, &'a mut Value)> + 'a>;
+pub type InlineTableIterMut<'a> = Box<dyn Iterator<Item = (KeyMut<'a>, &'a mut Value)> + 'a>;
 
 impl TableLike for InlineTable {
     fn iter(&self) -> Iter<'_> {
@@ -364,7 +355,7 @@ impl TableLike for InlineTable {
         Box::new(
             self.items
                 .iter_mut()
-                .map(|(key, kv)| (&key[..], &mut kv.value)),
+                .map(|(_, kv)| (kv.key.as_mut(), &mut kv.value)),
         )
     }
     fn get<'s>(&'s self, key: &str) -> Option<&'s Item> {
